@@ -13,7 +13,6 @@ from pathlib import Path
 from sys import exit
 from tempfile import NamedTemporaryFile
 
-import pkg_resources
 from colorama import init as colorama_init, Fore
 from dialog import Dialog, DialogError
 from prompt_toolkit import PromptSession, HTML
@@ -21,8 +20,9 @@ from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.shortcuts import clear
 from validate_email import validate_email
 
-from .attachment import Contacts, Attachment
+from .attachment import Attachment
 from .config import Config, get_terminal_size, console_handler, edit, get_path
+from .contacts import Contacts
 from .decorators import PickBase, PickMethod, PickInput
 from .dialogue import Cancelled, Debugged, Menu, pick_option, ask, ask_number, is_yes
 from .field import Field
@@ -37,10 +37,8 @@ logger = logging.getLogger(__name__)
 aggregate_functions = [f for f in Aggregate.__dict__ if not f.startswith("_")]
 aggregate_functions_str = "".join("\n* " + f for f in aggregate_functions)
 
-try:
-    __version__ = pkg_resources.require("convey")[0].version
-except pkg_resources.DistributionNotFound:
-    __version__ = "unknown"
+# I really do not like to have an extra file for this. Change my mind.
+__version__ = "1.4"  # to be changed in setup.py too
 
 
 def send_ipc(pipe, msg, refresh_stdout):
@@ -157,7 +155,8 @@ class Controller:
             Config.set("disable_external", True)
         Types.refresh()  # load types so that we can print out computable types in the help text
         epilog = "To launch a web service see README.md."
-        column_help = "COLUMN is ID of the column (1, 2, 3...), the exact column name, field type name or its usual name."
+        column_help = "COLUMN is ID of the column (1, 2, 3...), position from the right (-1, ...)," \
+                      " the exact column name, field type name or its usual name."
         parser = argparse.ArgumentParser(description="Data conversion swiss knife", formatter_class=SmartFormatter,
                                          epilog=epilog)
 
@@ -198,12 +197,6 @@ class Controller:
         group.add_argument('--compute-preview', help="When adding new columns, show few first computed values.",
                            action=BlankTrue, nargs="?", metavar="blank/false")
 
-        parser.add_argument('--csirt-incident', action="store_true",
-                            help="Macro that lets you split CSV by fetched incident-contact (whois abuse mail for local country"
-                                 " or csirt contact for foreign countries) and send everything by OTRS."
-                                 " You set local countries in config.ini, currently set to"
-                                 f" '{Config.get('local_country', 'FIELDS')}'")
-
         group = parser.add_argument_group("Environment")
         group.add_argument('--config', help="R|Open a config file and exit."
                                             "\n File: config (default)/uwsgi/template/template_abroad"
@@ -476,7 +469,8 @@ class Controller:
                     quit()
                 Config.set("stdout", args.output is True or None)
                 if args.output is True:
-                    # --output=True means no output will be produced in favour of stdout
+                    # --output=True → no output file in favour of stdout (Config.get("stdout") -> parser.stdout set)
+                    # --output=FILE → an output file generated (Config.get("output") -> parser.target_file set)
                     args.output = None
                 for flag in ["output", "web", "whois", "nmap", "dig", "delimiter", "quote_char", "compute_preview",
                              "user_agent",
@@ -625,14 +619,6 @@ class Controller:
                     # However, this is such a small change, we will not turning parser.is_processable on.
                     self.parser.settings["header"] = args.header_output
 
-                # start csirt-incident macro XX deprecated
-                if args.csirt_incident and not self.parser.is_analyzed:
-                    self.parser.settings["split"] = len(self.parser.fields)
-                    self.source_new_column(Types.incident_contact, add=False)
-                    self.parser.is_processable = True
-                    self.process()
-                    self.parser.is_processable = False
-
                 if self.parser.is_processable and Config.get("yes"):
                     self.process()
 
@@ -806,13 +792,7 @@ class Controller:
 
     def send_menu(self, method="smtp", test_attachment=None, send_now=False):
         # choose method SMTP/OTRS
-        if self.args.csirt_incident:
-            if Config.get("otrs_enabled", "OTRS"):
-                method = "otrs"
-            else:
-                print("You are using csirt-incident macro but otrs_enabled key is set to False in config.ini. Exiting.")
-                quit()
-        elif Config.get("otrs_enabled", "OTRS") and self.args.otrs_id:
+        if Config.get("otrs_enabled", "OTRS") and self.args.otrs_id:
             method = "otrs"
         elif Config.get("otrs_enabled", "OTRS") and not Config.get("yes"):
             menu = Menu(title="What sending method do we want to use?", callbacks=False, fullscreen=True)
@@ -1003,7 +983,7 @@ class Controller:
                 elif option == "r":
                     # choose recipient list
                     choices = [(o.mail,
-                                o.get_draft_name() + ("" if validate_email(o.mail, check_mx=False) else " (invalid)"),
+                                o.get_draft_name() + ("" if validate_email(o.mail, check_dns=False, check_smtp=False) else " (invalid)"),
                                 not o.sent)
                                for o in attachments]
                     code, tags = Dialog(autowidgetsize=True).checklist("Toggle e-mails to be send", choices=choices)
@@ -1370,7 +1350,7 @@ class Controller:
                 fields = self.parser.fields
 
                 for type_, items in st.items():
-                    # XXX code does not return its custom part
+                    # XX code does not return its custom part
                     if not items and items != 0:
                         continue
                     if type_ == "split":
@@ -1383,7 +1363,7 @@ class Controller:
                     elif type_ == "unique":
                         l.extend(f"--unique {fields[f].name}" for f in items)
                     elif type_ == "aggregate":
-                        # XXX does not work well - at least, they are printed out opposite way
+                        # XX does not work well - at least, they are printed out opposite way
                         l.append(f"--aggregate {items[0]}," + ",".join(
                             f"{fn.__name__},{fields[col].name}" for fn, col in items[1]))
                 if l:
@@ -1393,9 +1373,7 @@ class Controller:
         exit(0)
 
     def get_autocompletion(self, parser):
-        actions = []
-        for action in parser._actions:
-            actions.extend(action.option_strings)
+        actions = [x for action in parser._actions for x in action.option_strings]
 
         a = ["#!/usr/bin/env bash",
              "# bash completion for convey",
