@@ -16,7 +16,8 @@ from typing import List
 
 from tabulate import tabulate
 
-from .attachment import Contacts, Attachment
+from .attachment import Attachment
+from .contacts import Contacts
 from .config import Config, get_terminal_size
 from .dialogue import Cancelled, is_yes, ask
 from .field import Field
@@ -96,6 +97,8 @@ class Parser:
         # When accepting input from stdin and not saving the output into a file
         #   or when setting this to True,
         #   the output will be here.
+        # Config.get("output") - the file we should save to
+        # Config.get("stdout") - stdout used
         self.stdout = Config.get("stdout")
         self.stdout_sample = None
         self.target_file = None
@@ -401,11 +404,6 @@ class Parser:
             if type(field) is Type or field.is_chosen:
                 append(field, val)
 
-        # prepare json to return (useful in a web service)
-        if "csirt-contact" in data and data["csirt-contact"] == "-":
-            # empty value instead of a dash, stored in CsvGuesses-method-("whois", "csirt-contact")
-            data["csirt-contact"] = ""
-
         # output in text, json or file
         if Config.get("output"):
             logger.info(f"Writing to {self.target_file}...")
