@@ -25,8 +25,8 @@ from netaddr import IPRange, IPNetwork
 from pint import UnitRegistry
 from validate_email import validate_email
 
-from .attachment import Contacts
 from .config import Config
+from .contacts import Contacts
 from .decorators import PickBase, PickMethod, PickInput
 from .graph import Graph
 from .infodicts import phone_regex_match, phone_country, address_country, country_codes
@@ -215,7 +215,11 @@ class Checker:
             return False
         s = wrong_url_2_url(wrong, make=False)
         s2 = wrong_url_2_url(wrong, make=True)
-        netloc = urlparse(s2).netloc
+        try:
+            netloc = urlparse(s2).netloc
+        except ValueError:
+            # ex: s2='http://[07/Feb/2021:00:32:43 -0500] "GET /wp-json/wp/v2/posts HTTP/1.1" 200 1912'
+            return False
         # Xm = reUrl.match(s2)
         if reFqdn.match(s) or reFqdn.match(netloc) or is_ip(netloc):  # X(m and m.span(0)[1] == len(s2) and "." in s2):
             # Xwe impose full match
@@ -268,10 +272,21 @@ class Checker:
 
     @staticmethod
     def is_timestamp(val):
+        reference = datetime.now()
+
+        # identify UNIX time
+        try:
+            o = datetime.fromtimestamp(float(val))
+        except ValueError:
+            pass  # val is not a number, try different methods
+        else:
+            # consider only nowadays timestamp a timestamp
+            # prevent "12345" to be considered as a timestamp from the beginning of the Unix epoch (1970)
+            return reference.year - 5 < o.year < reference.year + 1
+
         # identify straight textual representation (ex: 2021-02-12), easily parsable by not-fuzzy `dateutil`
         try:
             o = dateutil.parser.parse(val)
-            reference = datetime.now()
             if not (o.second == o.minute == o.hour == 0 and o.day == reference.day and o.month == reference.month):
                 # if parser accepts a plain number, ex: 1920,
                 # it thinks this is a year without time (assigns midnight) and without date (assigns current date)
@@ -283,7 +298,7 @@ class Checker:
         except OverflowError:
             return False
 
-        # identify random textual representation of a timestamp or a Unix time
+        # identify random textual representation of a timestamp
         try:
             o = Checker.parse_timestamp(val)
             if 2100 > o.year > 1900 and not (o.second == o.minute == o.hour == 0 and o.day == o.month == 1):
@@ -435,7 +450,7 @@ class Web:
                 self.cache[url] = self.get = str(s), None, None, redirects, None, None, None
                 print_atomic(f"Scrapping {url} failed: {e}")
                 break
-            if response.headers.get("Location"):
+            if response.headers.get("Location") and len(redirects) < 10:
                 current_url = urljoin(current_url, response.headers.get("Location"))
                 redirects.append(current_url)
                 continue
@@ -448,7 +463,7 @@ class Web:
                     if res:
                         wait, txt = res[0].attrs["content"].split(";")
                         m = re.search(r"http[^\"'\s]*", txt)
-                        if m:
+                        if m and len(redirects) < 10:
                             current_url = m.group(0)
                             redirects.append(current_url)
                             continue
@@ -827,6 +842,12 @@ class Types:
                          "E-mail address corresponding with country code, taken from your personal contacts_abroad CSV"
                          " in the format `country,abusemail`. See config.ini/contacts_abroad")
     incident_contact = Type("incident_contact", TypeGroup.whois)
+    cc_contact = Type("cc_contact", TypeGroup.whois,
+                      "E-mail address corresponding with the abusemail, taken from your personal contacts_cc CSV"
+                      " in the format `domain,cc;cc` (mails delimited by a semicolon). See config.ini/contacts_cc."
+                      " Note:  when sending an e-mail to a csirt_contact, the e-mail template fills Cc header"
+                      " from the csirt_contact through contacts_cc.csv too. So you may end up with another Cc field"
+                      " than in cc_contact.")
     text = Type("text", TypeGroup.web)
     http_status = Type("http_status", TypeGroup.web, "HTTP response status. If 0 or negative, request failed.")
     html = Type("html", TypeGroup.web)
@@ -868,7 +889,8 @@ class Types:
                   lambda x: reAnyIp.search(x) and not is_ip(x))
     hostname = Type("hostname", TypeGroup.general, "2nd or 3rd domain name", ["fqdn", "hostname", "domain"],
                     reFqdn.match)
-    email = Type("email", TypeGroup.general, "E-mail address", ["mail"], lambda e: validate_email(e, check_mx=False))
+    email = Type("email", TypeGroup.general, "E-mail address", ["mail"],
+                 lambda e: validate_email(e, check_dns=False, check_smtp=False))
     url = Type("url", TypeGroup.general, "URL starting with http/https", ["url", "uri", "location"],
                lambda s: reUrl.match(s) and "[.]" not in s)  # input "example[.]com" would be admitted as a valid URL)
     asn = Type("asn", TypeGroup.whois, "Autonomous system number", ["as", "asn", "asnumber"],
@@ -879,6 +901,7 @@ class Types:
     urlencode = Type("urlencode", TypeGroup.general, "Text encoded with urlencode", ["urlencode"], Checker.is_urlencode)
     wrong_url = Type("wrong_url", TypeGroup.general, "Deactivated URL", [], Checker.check_wrong_url)
     plaintext = Type("plaintext", TypeGroup.general, "Plain text", ["plaintext", "text"], lambda x: False)
+    path = Type("path", usual_names=["path"], identify_method = lambda x: False)
 
     @staticmethod
     def get_computable_types(ignore_custom=False):
@@ -1027,9 +1050,12 @@ class Types:
             (t.whois, t.abusemail): lambda x: x.get[6],
             (t.whois, t.country): lambda x: x.get[5],
             (t.whois, t.netname): lambda x: x.get[4],
-            (t.whois, t.csirt_contact): lambda x: Contacts.country2mail[x.get[5]] if x.get[
-                                                                                         5] in Contacts.country2mail else "-",
+            (t.whois, t.csirt_contact):
+                lambda x: Contacts.country2mail[x.get[5]] if x.get[5] in Contacts.country2mail else "",
             (t.whois, t.incident_contact): lambda x: x.get[2],
+            (t.abusemail, t.cc_contact): lambda x: "; ".join(
+                Contacts.mail2cc[domain] for domain in Contacts.get_domains(x) if domain in Contacts.mail2cc
+            ),
             (t.plaintext, t.bytes): lambda x: x.encode("UTF-8"),
             (t.bytes, t.plaintext): Checker.bytes_plaintext,
             (t.bytes, t.base64): lambda x: b64encode(x).decode("UTF-8"),
@@ -1071,7 +1097,7 @@ class Types:
             # (t.email, check legit mailbox)
             (t.country_name, t.country): address_country,
             (t.country, t.country_name): lambda x: country_codes[x],
-            (t.country, t.csirt_contact): lambda x: Contacts.country2mail[x] if x in Contacts.country2mail else "-",
+            (t.country, t.csirt_contact): lambda x: Contacts.country2mail[x] if x in Contacts.country2mail else "",
             (t.phone, t.country): phone_country,
             (t.hostname, t.tld): Checker.HostnameTld,
             (t.prefix, t.cidr): Checker.prefix_cidr,
