@@ -83,7 +83,8 @@ class Wrapper:
             stdin = file_or_input.split("\n") if file_or_input else read_stdin()
         elif force_file:
             file = file_or_input if file_or_input else choose_file()
-        elif file_or_input and Path(file_or_input).is_file():
+        elif file_or_input and len(file_or_input) < 256 and Path(file_or_input).is_file():
+            # if longer than 255, it is most probably not a file but input
             file = file_or_input
         elif file_or_input:
             stdin = file_or_input.split("\n")
@@ -166,7 +167,8 @@ class Wrapper:
     def assure_cache_file(self, file):
         self.file = Path(file).resolve()
         info = self.file.stat()
-        hash_ = str(hash(info.st_size + round(info.st_mtime)))
+        hash_ = str(hash(info.st_size + round(info.st_mtime)))  # XX use st_size only?
+
         # cache-file with source file metadata
         Config.set_cache_dir(Path(self.file.parent, self.file.name + "_convey" + hash_))
         self.cache_file = Path(Config.get_cache_dir(), self.file.name + ".cache")
@@ -175,7 +177,8 @@ class Wrapper:
         """ restore whois cache and remove expired results """
         p = Path(config_dir, WHOIS_CACHE)
         if Config.get("whois_cache", "FIELDS", get=bool) and p.exists():
-            event = lazy_print("... loading big WHOIS cache ...")  # XX if it's long, postpone via a thread that would block analysis
+            # XX if it's long, postpone via a thread that would block analysis
+            event = lazy_print("... loading big WHOIS cache ...")
             ip_seen, ranges = jsonpickle.decode(p.read_text(), keys=True)
             ranges = {IPRange(k[0], k[1]): v for k, v in ranges.items()
                       if v[7] + Config.get("whois_ttl", "FIELDS", int) >= time()}
@@ -205,7 +208,8 @@ class Wrapper:
     # Store
     def save(self, last_chance=False):
         # chance to save the original file to the disk if reading from STDIN
-        if not self.cache_file and ((self.parser.stdout is not True and self.parser.stdout) or self.parser.is_formatted):
+        if not self.cache_file and \
+                ((self.parser.stdout is not True and self.parser.stdout) or self.parser.is_formatted):
             # * cache_file does not exist = we have not written anything on the disk
             # * target_file exist = there is a destination to write (when splitting, no target_file specified)
             #       XX which may be changed because it is usual to preserve file
@@ -292,7 +296,6 @@ class Wrapper:
                         event.set()
             self.cache_file.write_text(string)  # save cache
 
-
     def clear(self):
         self.check_xls() or self.check_ods() or self.check_log()
 
@@ -373,7 +376,7 @@ class Wrapper:
                 except AttributeError:
                     pass
                 finally:
-                    # XXX however, this resets the cache of the file because we continue in the clear() method
+                    # XX however, this resets the cache of the file because we continue in the clear() method
                     #   We rather do want to directly go to the file.
                     self.assure_cache_file(target.absolute())  # changes self.file
                     return
